@@ -22,6 +22,7 @@ from solum.tests import base
 from solum.tests import fakes
 
 
+@mock.patch('solum.common.policy.check')
 @mock.patch('pecan.request', new_callable=fakes.FakePecanRequest)
 @mock.patch('pecan.response', new_callable=fakes.FakePecanResponse)
 @mock.patch('solum.api.handlers.assembly_handler.AssemblyHandler')
@@ -30,8 +31,9 @@ class TestAssemblyController(base.BaseTestCase):
         super(TestAssemblyController, self).setUp()
         objects.load()
 
-    def test_assembly_get(self, AssemblyHandler, resp_mock, request_mock):
-        self.policy({'show_assembly': '@'})
+    def test_assembly_get(self, AssemblyHandler, resp_mock,
+                          request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_get = AssemblyHandler.return_value.get
         fake_assembly = fakes.FakeAssembly()
         hand_get.return_value = fake_assembly
@@ -51,8 +53,8 @@ class TestAssemblyController(base.BaseTestCase):
         self.assertEqual(200, resp_mock.status)
 
     def test_assembly_get_not_found(self, AssemblyHandler,
-                                    resp_mock, request_mock):
-        self.policy({'show_assembly': '@'})
+                                    resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_get = AssemblyHandler.return_value.get
         hand_get.side_effect = exception.ResourceNotFound(
             name='assembly', assembly_id='test_id')
@@ -61,8 +63,9 @@ class TestAssemblyController(base.BaseTestCase):
         hand_get.assert_called_with('test_id')
         self.assertEqual(404, resp_mock.status)
 
-    def test_assembly_put_none(self, AssemblyHandler, resp_mock, request_mock):
-        self.policy({'update_assembly': '@'})
+    def test_assembly_put_none(self, AssemblyHandler, resp_mock,
+                               request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.body = None
         request_mock.content_type = 'application/json'
         hand_put = AssemblyHandler.return_value.put
@@ -71,8 +74,8 @@ class TestAssemblyController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_assembly_put_not_found(self, AssemblyHandler,
-                                    resp_mock, request_mock):
-        self.policy({'update_assembly': '@'})
+                                    resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         json_update = {'name': 'foo'}
         request_mock.body = json.dumps(json_update)
         request_mock.content_type = 'application/json'
@@ -83,8 +86,9 @@ class TestAssemblyController(base.BaseTestCase):
         hand_update.assert_called_with('test_id', json_update)
         self.assertEqual(404, resp_mock.status)
 
-    def test_assembly_put_ok(self, AssemblyHandler, resp_mock, request_mock):
-        self.policy({'update_assembly': '@'})
+    def test_assembly_put_ok(self, AssemblyHandler, resp_mock,
+                             request_mock, mock_policy):
+        mock_policy.return_value = True
         json_update = {'name': 'foo'}
         request_mock.body = json.dumps(json_update)
         request_mock.content_type = 'application/json'
@@ -95,8 +99,8 @@ class TestAssemblyController(base.BaseTestCase):
         self.assertEqual(200, resp_mock.status)
 
     def test_assembly_delete_not_found(self, AssemblyHandler,
-                                       resp_mock, request_mock):
-        self.policy({'delete_assembly': '@'})
+                                       resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_delete = AssemblyHandler.return_value.delete
         hand_delete.side_effect = exception.ResourceNotFound(
             name='assembly', assembly_id='test_id')
@@ -106,8 +110,8 @@ class TestAssemblyController(base.BaseTestCase):
         self.assertEqual(404, resp_mock.status)
 
     def test_assembly_delete_ok(self, AssemblyHandler,
-                                resp_mock, request_mock):
-        self.policy({'delete_assembly': '@'})
+                                resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_delete = AssemblyHandler.return_value.delete
         hand_delete.return_value = None
         obj = assembly.AssemblyController('test_id')
@@ -143,6 +147,7 @@ class TestAssemblyAsDict(base.BaseTestCase):
         self.assertEqual(self.data, s.as_dict(objects.registry.Assembly))
 
 
+@mock.patch('solum.common.policy.check')
 @mock.patch('pecan.request', new_callable=fakes.FakePecanRequest)
 @mock.patch('pecan.response', new_callable=fakes.FakePecanResponse)
 @mock.patch('solum.api.handlers.assembly_handler.AssemblyHandler')
@@ -152,8 +157,8 @@ class TestAssembliesController(base.BaseTestCase):
         objects.load()
 
     def test_assemblies_get_all(self, AssemblyHandler,
-                                resp_mock, request_mock):
-        self.policy({'get_assemblies': '@'})
+                                resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         hand_get = AssemblyHandler.return_value.get_all
         fake_assembly = fakes.FakeAssembly()
         hand_get.return_value = [fake_assembly]
@@ -172,8 +177,8 @@ class TestAssembliesController(base.BaseTestCase):
 
     @mock.patch('solum.objects.registry.Plan')
     def test_assemblies_post(self, mock_Plan, AssemblyHandler,
-                             resp_mock, request_mock):
-        self.policy({'create_assembly': '@'})
+                             resp_mock, request_mock, mock_policy):
+        mock_policy.return_value = True
         json_create = {'name': 'foo',
                        'plan_uri': 'http://test_url:8080/test/911'}
         request_mock.body = json.dumps(json_create)
@@ -190,8 +195,8 @@ class TestAssembliesController(base.BaseTestCase):
         self.assertEqual(201, resp_mock.status)
 
     def test_assemblies_post_no_plan(self, AssemblyHandler, resp_mock,
-                                     request_mock):
-        self.policy({'create_assembly': '@'})
+                                     request_mock, mock_policy):
+        mock_policy.return_value = True
         json_create = {'name': 'foo'}
         request_mock.body = json.dumps(json_create)
         request_mock.content_type = 'application/json'
@@ -205,8 +210,8 @@ class TestAssembliesController(base.BaseTestCase):
         self.assertEqual(400, resp_mock.status)
 
     def test_assemblies_post_not_hosted(self, AssemblyHandler, resp_mock,
-                                        request_mock):
-        self.policy({'create_assembly': '@'})
+                                        request_mock, mock_policy):
+        mock_policy.return_value = True
         json_create = {'name': 'foo',
                        'plan_uri': 'http://example.com/a.git'}
         request_mock.body = json.dumps(json_create)
@@ -218,8 +223,9 @@ class TestAssembliesController(base.BaseTestCase):
         self.assertIn('The plan was not hosted in solum', faultstring)
         self.assertEqual(400, resp_mock.status)
 
-    def test_assem_post_nodata(self, AssemblyHandler, resp_mock, request_mock):
-        self.policy({'create_assembly': '@'})
+    def test_assem_post_nodata(self, AssemblyHandler, resp_mock,
+                               request_mock, mock_policy):
+        mock_policy.return_value = True
         request_mock.body = ''
         request_mock.content_type = 'application/json'
         hand_create = AssemblyHandler.return_value.create
